var Player = {
  element: null,
  currentSceneIndex: 0,
  currentScene: null,
  screenWidth: window.availWidth,
  screenHeight: window.availHeight,
  screenRatio: 1,
  sceneTimeout: null,
  sectionTimeout: null,
  program: null,
  prevFileElement: null,

  start: function () {
    this.element = document.getElementById("player");
    widgetAPI.putInnerHTML(this.element, "");
    this.startProgram();
  },

  startProgram: function () {
    this.currentSceneIndex = 0;
    this.program = JSON.parse(Config.get("program"));
    this.startScene(this.program.scenes, this.currentSceneIndex);
  },

  startScene: function (scenes, index) {
    // Sona geldiysek tekrar başa dön
    if (index == scenes.length) {
      this.currentSceneIndex = 0;
      index = 0;
    }
    // console.log("start scene", index);
    this.currentScene = scenes[index];

    // Sahne yerleşimini yap
    this.sceneLayout(this.currentScene);

    // Sonraki sahne geçişi
    var sceneDuration = timeToMilliseconds(this.currentScene.duration);

    var self = this;
    this.sceneTimeout = setTimeout(function () {
      log("next scene");
      // clearTimeout(self.sectionTimeout);
      // self.startScene(scenes, ++self.currentSceneIndex);
    }, sceneDuration);
  },

  sceneLayout: function (scene) {
    // player içini temizle
    widgetAPI.putInnerHTML(this.element, "");

    // if (screenWidth > screenHeight) {
    //   screenProgramRatio =
    //     scene.layout.width > screenWidth ? screenWidth / scene.layout.width : scene.layout.width / screenWidth;
    // } else {
    //   screenProgramRatio =
    //     scene.layout.height > screenHeight ? screenHeight / scene.layout.height : scene.layout.height / screenHeight;
    // }

    // Dikey ise

    var fixRatio =
      scene.layout.width > window.innerWidth
        ? window.innerWidth / scene.layout.width
        : scene.layout.width / window.innerWidth;

    var self = this;

    scene.layout.sections.map(function (section) {
      var div = document.createElement("div");
      div.className = "section";

      div.style.left = section.x * fixRatio + "px";
      div.style.top = section.y * fixRatio + "px";
      div.style.width = section.w * fixRatio + "px";
      div.style.height = section.h * fixRatio + "px";

      widgetAPI.putInnerHTML(self.element, div);

      self.startSection(div, section);
    });
  },

  startSection: function (div, section, self) {
    // log("items length: " + section.items.length);
    section.items.sort(function (a, b) {
      return a.nth - b.nth;
    });
    this.startItem(div, section.items, 0);
  },

  startItem: function (div, items, index) {
    log("show index " + index + " / " + items.length);

    if (typeof items[index] != "undefined") {
      var item = items[index];

      log("play index :" + index + " " + LOCAL_FILE_PATH + item.file_name);

      switch (item.type) {
        case "image":
          this.showImage(LOCAL_FILE_PATH + item.file_name);
          break;
        case "video":
          this.showVideo(LOCAL_FILE_PATH + item.file_name);
          break;
        case "url":
          var meta = JSON.parse(item.meta);
          this.showURL(meta.url);
          break;
      }

      var self = this;
      switch (item.type) {
        case "image":
        case "url":
        case "video":
          // Sonraki itema geç
          this.sectionTimeout = setTimeout(function () {
            var nextIndex = (index + 1) % items.length;
            self.startItem(div, items, nextIndex);
          }, item.duration);
          break;
        // case "video":
        //   videoElement.onended = function () {
        //     setTimeout(function () {
        //       startItem(div, items, ++index);
        //     }, 3000);
        //   };
        //   break;
      }
    } else {
      log("item hata :" + index + " " + typeof items[index]);
    }
  },

  showVideo: function (url) {
    var video = document.createElement("video");

    widgetAPI.putInnerHTML(this.element, "");

    this.element.appendChild(video);

    video.className = "play-item";
    video.src = url;
    video.preload = "auto";
    video.autoplay = true;
    video.muted = true;
    video.controls = false;
    video.loop = false;

    video.play();

    // this.removePrevElement();
    // this.prevFileElement = video;

    return video;
  },

  showImage: function (url) {
    var image = document.createElement("img");

    widgetAPI.putInnerHTML(this.element, "");

    this.element.appendChild(image);

    image.className = "play-item";
    image.src = url;

    // this.removePrevElement();
    // this.prevFileElement = image;
  },

  showURL: function (url) {
    var iframe = document.createElement("iframe");

    widgetAPI.putInnerHTML(this.element, "");

    // this.element.appendChild(iframe);
    iframe.className = "play-item";
    iframe.src = url;
    iframe.setAttribute("scrolling", "no");

    // this.removePrevElement();
    // this.prevFileElement = iframe;
  },

  removePrevElement: function () {
    if (this.prevFileElement) {
      this.prevFileElement.remove();
    }
  },
};
