var pluginDownload = document.getElementById("pluginDownload");
var pluginFileSystem = document.getElementById("pluginFileSystem");

var Storage = {
  localPath: "/mtd_down/common/" + widget.id + "/",
};

/**
 * Dosya indirme işlemi başlatır, tamamlandığında callback çalışır
 *
 * @param {string} url
 * @param {string} path
 * @param {function} downladCallback
 * @param {function} errorCallback
 */
Storage.downloadFile = function (url, path, downladCallback, errorCallback) {
  // Yerel dosya indirme yolu
  var downloadPath = this.getLocalPath(path);

  // Yerel dosya var ise boşuna indirmeye gerek yok
  if (this.isPathExist(downloadPath)) {
    downladCallback(downloadPath);

    // Dosya yok indirme işlemini kurgula
  } else {
    pluginDownload.OnComplete = function (msg) {
      var status = msg.split("?");
      switch (status[0]) {
        // Dosya indirme tamamlandı
        case "1000":
          if (status[1] == "1") {
            downladCallback(downloadPath);
          } else {
            errorCallback(downloadPath, msg);
            throw new Error("Download failed: " + path + " - " + msg);
          }
          break;
        // İşlem devam ediyor
        case "1001":
          break;
      }
    };

    // Dosya indirme işlemi başlat
    pluginDownload.StartDownFile(url, downloadPath, 0, 5);
  }
};

// Dosyaları sırayla indirir

var downloadNextFile = function (files, index, callback) {
  if (index >= files.length) {
    // Tüm dosyalar indirildi, callback'i çağır
    callback();
    return;
  }

  var file = files[index];
  var baseUrl = "http://sssp.octoservice.net/storage/";

  Storage.downloadFile(
    baseUrl + file,
    file,
    function (downloadedPath) {
      // Dosya indirildi, bir sonraki dosyayı indir
      log("Downloaded: " + downloadedPath);
      downloadNextFile(files, index + 1, callback);
    },
    function (errorPath, errorMsg) {
      // Hata oluştu, callback'e hata bilgisini gönder
      log("Download failed: " + errorPath + " - " + errorMsg);
      callback(errorPath, errorMsg);
    }
  );
};

Storage.downloadFiles = function (files, callback) {
  downloadNextFile(files, 0, function (errorPath, errorMsg) {
    if (errorPath) {
      // Hata oluştu, callback'e hata bilgisini gönder
      callback(errorPath, errorMsg);
    } else {
      // Tüm dosyalar indirildi, callback'i çağır
      callback();
    }
  });
};

/**
 * Verilen yolu local storage içindeki tam yolunu döndürür
 *
 * @param {string} path
 * @returns
 */
Storage.getLocalPath = function (path) {
  return this.localPath + path;
};

/**
 * İstenen path gerçekten var mı yok mu kontrol eder
 *
 * @param {string} path
 * @returns
 */
Storage.isPathExist = function (path) {
  return pluginFileSystem.IsExistedPath(path);
};

/**
 * Dosya silme işlemi yapar
 *
 * @param {string} path
 */
Storage.deleteFile = function (path) {
  if (this.isPathExist(path)) {
    log("Silinecek dosya var: " + path);
    fileSystem.deleteCommonFile(path);
  } else {
    throw new Error("File not found: " + path);
  }
};
